#!/usr/bin/env python
# -*- coding: utf-8 -*-
## @brief Generate a simple maze pattern.
#
#Tip of the hat to both the original Commodore 64 program and the book
#"10 Print Chr$(205.5+rnd(1)); Goto 10" that it inspired.
#
#Note that this is neither the shortest nor the most faithful way to
#write this program in Python. Rather it is being used as a simple
#example for the doxypypy Doxygen input filter for Python and makes use
#of features like keyword arguments and generators and has a docstring
#that documents them both appropriately.
#
# @namespace sample_maze


from sys import stdout
from random import choice


## @brief     Generates a single block of a maze.
#
#    This simple generator randomly picks a character from a list (the two
#    diagonal lines by default) and returns it on each iteration.
#
#
# @param		blockOptions	The list of characters to choose from.
#
# @return
#        A single character chosen from blockOptions.
#
# @namespace sample_maze.generateBlock

def generateBlock(blockOptions=u"╱╲"):
    while True:
        yield choice(blockOptions)


# Establish our block generator and generate a series of blocks.
blockGenerator = generateBlock()
blockCount = 0
while blockCount < 3200:
    blockCount += 1
    print(next(blockGenerator)),
    # Deal with Python's extra space print weirdness.
    stdout.softspace = False



# -*- coding: utf-8 -*-
##
#An asynchronous function and an asynchronous method.
#
#Here we're testing out some straightforward Python 3 async
#examples.
#


##
#    A sample non-asynchronous function.
#
def non_asynchronous_function():
    return "Not async."

##
#    A sample asynchronous function.
#
async def asynchronous_function():
    return "Async"


##
#    A sample class with an async method.
#
#    Nothing special, just a basic Python 3 class that has an
#    async method in it.
#
class ClassWithAsyncMethod():

    ##
    #        This is a regular, non-async method.
    #
    def non_asynchronous_method(self):
        return "Not async."

    ##
    #        This is an asynchronous method.
    #
    async def asynchronous_method(self):
        return "Async"




#!/bin/env python
# UTF-32-LE Python File with a BOM

## @brief A UTF-32LE File identified by BOM.
#
#This doesn't have much to it, but it identifies itself
#using a BOM rather than a coding line.
#
# @note
#	See how doxypypy converts this note and the
#	following warning.
#
# @warning
#	Be sure to save this file in the proper encoding.
#
# @namespace sample_utf32lebom

print('Hello, I am in UTF-32LE encoding.')



#!/usr/bin/env python
# As close as possible to a direct copy of the sample in PEP 257 and still
# be valid code. Simple as can be.

complex_zero = 0j


def complex(real=0.0, imag=0.0):
    """Form a complex number.

    Keyword arguments:
    real -- the real part (default 0.0)
    imag -- the imaginary part (default 0.0)

    """
    if imag == 0.0 and real == 0.0:
        return complex_zero
    else:
        return complex(real, imag)



#!/bin/env python
# UTF-16-LE Python File with a BOM

"""
A UTF-16LE File identified by BOM.

This doesn't have much to it, but it identifies itself
using a BOM rather than a coding line.

Note:
	See how doxypypy converts this note and the
	following warning.

Warning:
	Be sure to save this file in the proper encoding.
"""
print('Hello, I am in UTF-16LE encoding.')



# -*- coding: utf-8 -*-
## @brief Typical class with private members.
#
#Here we're just trying to make a fairly straightforward class
#that has some private (Python-enforced private, name-mangled)
#and protected (by convention only, a.k.a. "bed lump")
#variables.
#
# @namespace sample_privacy

__notPrivateModuleAttr__ = 1
## @var __privateModuleAttr
# @hideinitializer
# @private
__privateModuleAttr = 2
## @var _protectedModuleAttr
# @hideinitializer
# @protected
_protectedModuleAttr = 3


## @brief     A sample new-style class.
#
#    Nothing special, just a basic new-style class that has some
#    private and protected members in it.
#
# @namespace sample_privacy.NewStyleSample

class NewStyleSample():

    __notPrivateClassAttr__ = 1
    ## @var __privateClassAttr
    # @hideinitializer
    # @private
    __privateClassAttr = 2
    ## @var _protectedClassAttr
    # @hideinitializer
    # @protected
    _protectedClassAttr = 3

    ## @brief         This constructor won't be private.
    #
    # @namespace sample_privacy.NewStyleSample.__init__

    def __init__(self):
        self.__notPrivateAttr__ = 1
        self.__privateAttr = 2
        self._protectedAttr = 3

    ## @brief         This will be not be private.
    #
    # @namespace sample_privacy.NewStyleSample.__notPrivateClassMethod__

    def __notPrivateClassMethod__(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ## @brief         This will be private.
    #
    # @namespace sample_privacy.NewStyleSample.__privateClassMethod
    # @private

    def __privateClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ## @brief         This will be protected.
    #
    # @namespace sample_privacy.NewStyleSample._protectedClassMethod
    # @protected

    def _protectedClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ## @brief         This will be public.
    #
    # @namespace sample_privacy.NewStyleSample.publicClassMethod

    def publicClassMethod(self):
        public = 0
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.public = public
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    @staticmethod
    ## @brief         This static method will be public.
    #
    # @namespace sample_privacy.NewStyleSample.publicClassStaticMethod

    def publicClassStaticMethod():
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    @classmethod
    ## @brief         This class method will be public.
    #
    # @namespace sample_privacy.NewStyleSample.publicClassClassMethod

    def publicClassClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         An inner not private class.
    #
    #        Nothing special, just a not private helper class.
    #
    # @namespace sample_privacy.NewStyleSample.__innerNotPrivate__

    class __innerNotPrivate__():

        ## @brief             This constructor won't be private.
        #
        # @namespace sample_privacy.NewStyleSample.__innerNotPrivate__.__init__

        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ## @brief         An inner protected class.
    #
    #        Nothing special, just a protected helper class.
    #
    # @namespace sample_privacy.NewStyleSample.__innerProtected
    # @private

    class __innerProtected():

        ## @brief             This constructor won't be private.
        #
        # @namespace sample_privacy.NewStyleSample.__innerProtected.__init__

        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ## @brief         An inner private class.
    #
    #        Nothing special, just a private helper class.
    #
    # @namespace sample_privacy.NewStyleSample.__innerPrivate
    # @private

    class __innerPrivate():

        ## @brief             This constructor won't be private.
        #
        # @namespace sample_privacy.NewStyleSample.__innerPrivate.__init__

        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3


## @brief     A sample old-style class.
#
#    Nothing special, just a basic old-style class that has some
#    private and protected members in it.
#
# @namespace sample_privacy.OldStyleSample

class OldStyleSample():

    __notPrivateClassAttr__ = 1
    ## @var __privateClassAttr
    # @hideinitializer
    # @private
    __privateClassAttr = 2
    ## @var _protectedClassAttr
    # @hideinitializer
    # @protected
    _protectedClassAttr = 3

    ## @brief         This constructor won't be private.
    #
    # @namespace sample_privacy.OldStyleSample.__init__

    def __init__(self):
        self.__notPrivateAttr__ = 1
        self.__privateAttr = 2
        self._protectedAttr = 3

    ## @brief         This will be not be private.
    #
    # @namespace sample_privacy.OldStyleSample.__notPrivateClassMethod__

    def __notPrivateClassMethod__(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ## @brief         This will be private.
    #
    # @namespace sample_privacy.OldStyleSample.__privateClassMethod
    # @private

    def __privateClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ## @brief         This will be protected.
    #
    # @namespace sample_privacy.OldStyleSample._protectedClassMethod
    # @protected

    def _protectedClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ## @brief         This will be public.
    #
    # @namespace sample_privacy.OldStyleSample.publicClassMethod

    def publicClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    @staticmethod
    ## @brief         This static method will be public.
    #
    # @namespace sample_privacy.OldStyleSample.publicClassStaticMethod

    def publicClassStaticMethod():
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    @classmethod
    ## @brief         This class method will be public.
    #
    # @namespace sample_privacy.OldStyleSample.publicClassClassMethod

    def publicClassClassMethod(self):
        public = 0
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.public = public
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         An inner not private class.
    #
    #        Nothing special, just a not private helper class.
    #
    # @namespace sample_privacy.OldStyleSample.__innerNotPrivate__

    class __innerNotPrivate__():

        ## @brief             This constructor won't be private.
        #
        # @namespace sample_privacy.OldStyleSample.__innerNotPrivate__.__init__

        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ## @brief         An inner protected class.
    #
    #        Nothing special, just a protected helper class.
    #
    # @namespace sample_privacy.OldStyleSample.__innerProtected
    # @private

    class __innerProtected():

        ## @brief             This constructor won't be private.
        #
        # @namespace sample_privacy.OldStyleSample.__innerProtected.__init__

        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ## @brief         An inner private class.
    #
    #        Nothing special, just a private helper class.
    #
    # @namespace sample_privacy.OldStyleSample.__innerPrivate
    # @private

    class __innerPrivate():

        ## @brief             This constructor won't be private.
        #
        # @namespace sample_privacy.OldStyleSample.__innerPrivate.__init__

        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3


## @brief     A sample function.
#
#    Nothing special, just a basic function that has some private
#    and protected variables in it.
#
# @namespace sample_privacy.Function

def Function():
    __notPrivateFunctionAttr__ = 1
    ## @var __privateFunctionAttr
    # @hideinitializer
    # @private
    __privateFunctionAttr = 2
    ## @var _protectedFunctionAttr
    # @hideinitializer
    # @protected
    _protectedFunctionAttr = 3

    ## @brief         This will not be private.
    #
    # @namespace sample_privacy.Function.__notPrivateFunction__

    def __notPrivateFunction__():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be private.
    #
    # @namespace sample_privacy.Function.__privateNestedFunction
    # @private

    def __privateNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be protected.
    #
    # @namespace sample_privacy.Function._protectedNestedFunction
    # @protected

    def _protectedNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be public.
    #
    # @namespace sample_privacy.Function.publicNestedFunction

    def publicNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction


## @brief     A sample protected function.
#
#    Nothing special, just a basic protected function that has some
#    private and protected variables in it.
#
# @namespace sample_privacy._ProtectedFunction
# @protected

def _ProtectedFunction():
    __notPrivateFunctionAttr__ = 1
    ## @var __privateFunctionAttr
    # @hideinitializer
    # @private
    __privateFunctionAttr = 2
    ## @var _protectedFunctionAttr
    # @hideinitializer
    # @protected
    _protectedFunctionAttr = 3

    ## @brief         This will not be private.
    #
    # @namespace sample_privacy._ProtectedFunction.__notPrivateFunction__

    def __notPrivateFunction__():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be private.
    #
    # @namespace sample_privacy._ProtectedFunction.__privateNestedFunction
    # @private

    def __privateNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be protected.
    #
    # @namespace sample_privacy._ProtectedFunction._protectedNestedFunction
    # @protected

    def _protectedNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be public.
    #
    # @namespace sample_privacy._ProtectedFunction.publicNestedFunction

    def publicNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction


## @brief     A sample private function.
#
#    Nothing special, just a basic private function that has some
#    private and protected variables in it.
#
# @namespace sample_privacy.__PrivateFunction
# @private

def __PrivateFunction():
    __notPrivateFunctionAttr__ = 1
    ## @var __privateFunctionAttr
    # @hideinitializer
    # @private
    __privateFunctionAttr = 2
    ## @var _protectedFunctionAttr
    # @hideinitializer
    # @protected
    _protectedFunctionAttr = 3

    ## @brief         This will not be private.
    #
    # @namespace sample_privacy.__PrivateFunction.__notPrivateFunction__

    def __notPrivateFunction__():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be private.
    #
    # @namespace sample_privacy.__PrivateFunction.__privateNestedFunction
    # @private

    def __privateNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be protected.
    #
    # @namespace sample_privacy.__PrivateFunction._protectedNestedFunction
    # @protected

    def _protectedNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ## @brief         This will be public.
    #
    # @namespace sample_privacy.__PrivateFunction.publicNestedFunction

    def publicNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction



# -*- coding: utf-8 -*-
##
#Typical class with private members.
#
#Here we're just trying to make a fairly straightforward class
#that has some private (Python-enforced private, name-mangled)
#and protected (by convention only, a.k.a. "bed lump")
#variables.
#
__notPrivateModuleAttr__ = 1
## @var __privateModuleAttr
# @hideinitializer
# @private
__privateModuleAttr = 2
## @var _protectedModuleAttr
# @hideinitializer
# @protected
_protectedModuleAttr = 3


##
#    A sample new-style class.
#
#    Nothing special, just a basic new-style class that has some
#    private and protected members in it.
#
class NewStyleSample():

    __notPrivateClassAttr__ = 1
    ## @var __privateClassAttr
    # @hideinitializer
    # @private
    __privateClassAttr = 2
    ## @var _protectedClassAttr
    # @hideinitializer
    # @protected
    _protectedClassAttr = 3

    ##
    #        This constructor won't be private.
    #
    def __init__(self):
        self.__notPrivateAttr__ = 1
        self.__privateAttr = 2
        self._protectedAttr = 3

    ##
    #        This will be not be private.
    #
    def __notPrivateClassMethod__(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ##
    #        This will be private.
    #
    #
    # @private
    def __privateClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ##
    #        This will be protected.
    #
    #
    # @protected
    def _protectedClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ##
    #        This will be public.
    #
    def publicClassMethod(self):
        public = 0
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.public = public
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    @staticmethod
    ##
    #        This static method will be public.
    #
    def publicClassStaticMethod():
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    @classmethod
    ##
    #        This class method will be public.
    #
    def publicClassClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        An inner not private class.
    #
    #        Nothing special, just a not private helper class.
    #
    class __innerNotPrivate__():

        ##
        #            This constructor won't be private.
        #
        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ##
    #        An inner protected class.
    #
    #        Nothing special, just a protected helper class.
    #
    #
    # @private
    class __innerProtected():

        ##
        #            This constructor won't be private.
        #
        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ##
    #        An inner private class.
    #
    #        Nothing special, just a private helper class.
    #
    #
    # @private
    class __innerPrivate():

        ##
        #            This constructor won't be private.
        #
        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3


##
#    A sample old-style class.
#
#    Nothing special, just a basic old-style class that has some
#    private and protected members in it.
#
class OldStyleSample():

    __notPrivateClassAttr__ = 1
    ## @var __privateClassAttr
    # @hideinitializer
    # @private
    __privateClassAttr = 2
    ## @var _protectedClassAttr
    # @hideinitializer
    # @protected
    _protectedClassAttr = 3

    ##
    #        This constructor won't be private.
    #
    def __init__(self):
        self.__notPrivateAttr__ = 1
        self.__privateAttr = 2
        self._protectedAttr = 3

    ##
    #        This will be not be private.
    #
    def __notPrivateClassMethod__(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ##
    #        This will be private.
    #
    #
    # @private
    def __privateClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ##
    #        This will be protected.
    #
    #
    # @protected
    def _protectedClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    ##
    #        This will be public.
    #
    def publicClassMethod(self):
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    @staticmethod
    ##
    #        This static method will be public.
    #
    def publicClassStaticMethod():
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    @classmethod
    ##
    #        This class method will be public.
    #
    def publicClassClassMethod(self):
        public = 0
        __notPrivateAttr__ = 1
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = 2
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = 3
        self.public = public
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        An inner not private class.
    #
    #        Nothing special, just a not private helper class.
    #
    class __innerNotPrivate__():

        ##
        #            This constructor won't be private.
        #
        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ##
    #        An inner protected class.
    #
    #        Nothing special, just a protected helper class.
    #
    #
    # @private
    class __innerProtected():

        ##
        #            This constructor won't be private.
        #
        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    ##
    #        An inner private class.
    #
    #        Nothing special, just a private helper class.
    #
    #
    # @private
    class __innerPrivate():

        ##
        #            This constructor won't be private.
        #
        def __init__(self):
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3


##
#    A sample function.
#
#    Nothing special, just a basic function that has some private
#    and protected variables in it.
#
def Function():
    __notPrivateFunctionAttr__ = 1
    ## @var __privateFunctionAttr
    # @hideinitializer
    # @private
    __privateFunctionAttr = 2
    ## @var _protectedFunctionAttr
    # @hideinitializer
    # @protected
    _protectedFunctionAttr = 3

    ##
    #        This will not be private.
    #
    def __notPrivateFunction__():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be private.
    #
    #
    # @private
    def __privateNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be protected.
    #
    #
    # @protected
    def _protectedNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be public.
    #
    def publicNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction


##
#    A sample protected function.
#
#    Nothing special, just a basic protected function that has some
#    private and protected variables in it.
#
#
# @protected
def _ProtectedFunction():
    __notPrivateFunctionAttr__ = 1
    ## @var __privateFunctionAttr
    # @hideinitializer
    # @private
    __privateFunctionAttr = 2
    ## @var _protectedFunctionAttr
    # @hideinitializer
    # @protected
    _protectedFunctionAttr = 3

    ##
    #        This will not be private.
    #
    def __notPrivateFunction__():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be private.
    #
    #
    # @private
    def __privateNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be protected.
    #
    #
    # @protected
    def _protectedNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be public.
    #
    def publicNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction


##
#    A sample private function.
#
#    Nothing special, just a basic private function that has some
#    private and protected variables in it.
#
#
# @private
def __PrivateFunction():
    __notPrivateFunctionAttr__ = 1
    ## @var __privateFunctionAttr
    # @hideinitializer
    # @private
    __privateFunctionAttr = 2
    ## @var _protectedFunctionAttr
    # @hideinitializer
    # @protected
    _protectedFunctionAttr = 3

    ##
    #        This will not be private.
    #
    def __notPrivateFunction__():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be private.
    #
    #
    # @private
    def __privateNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be protected.
    #
    #
    # @protected
    def _protectedNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    ##
    #        This will be public.
    #
    def publicNestedFunction():
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        ## @var __privateAttr
        # @hideinitializer
        # @private
        __privateAttr = __privateFunctionAttr
        ## @var _protectedAttr
        # @hideinitializer
        # @protected
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction



#!/usr/bin/env python
# encoding: utf-8
## @brief Sample documentation the arbitrary section handling.
#
#Related to issue #7 [1].
#
#[1]: https://github.com/Feneric/doxypypy/issues/7
#
# @namespace sample_sections



## @brief A simple function of two arguments.
#
#    This function takes two arguments, but does absolutely nothing with them.
#    However, it sends out a friendly greeting to the world.
#
#
# @param		arg1	The first argument
# @param		arg2	The second argument
#
# @return
#        A string stating "Hello World"
#
# @par Examples
#        >>> function(1, 2)
#        "Hello World"
#        >>> function('a', 'b')
#        "Hello World"
#
# @par Intent
#        The intent is to demonstrate sections like this one within docstrings.
#        How they behave with multiple lines.
# @par
#        And how they behave with multiple paragraphs.
#        That contain multiple lines.
#
#    Paragraphs standing by themselves without indentation, should be left alone.
#
# @namespace sample_sections.function
def function(arg1, arg2):
    return "Hello World"



#!/usr/bin/env python
# As close as possible to a direct copy of the sample in PEP 257 and still
# be valid code. Simple as can be.

complex_zero = 0j


##Form a complex number.
#
#    Keyword arguments:
#    real -- the real part (default 0.0)
#    imag -- the imaginary part (default 0.0)
#
#
def complex(real=0.0, imag=0.0):
    if imag == 0.0 and real == 0.0:
        return complex_zero
    else:
        return complex(real, imag)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Tests the doxypypy filter.

These tests may all be executed by running tox from the
root level of the project.
"""
import unittest
from argparse import Namespace
from os import linesep, sep
from os.path import basename, splitext
from ast import parse
from codecs import open as codecsOpen
from sys import version_info

from pytest import mark

from ..doxypypy import AstWalker


class TestDoxypypy(unittest.TestCase):
    """
    Define our doxypypy tests.
    """
    maxDiff = None

    __Options = Namespace(
        autobrief=True,
        autocode=True,
        debug=False,
        fullPathNamespace='dummy',
        topLevelNamespace='dummy',
        tablength=4,
        filename='dummy.py',
        object_respect=False,
        equalIndent=False,
        keepDecorators=False
    )
    __dummySrc = [
        "print('testing: one, two, three, & four') " + linesep,
        "print('is five.')\t" + linesep
    ]
    __strippedDummySrc = linesep.join([
        "print('testing: one, two, three, & four')",
        "print('is five.')"
    ])
    __sampleBasics = [
        {
            'name': 'onelinefunction',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionOneLine():
                """Here is the brief."""''',
            'expectedOutput': [
                '## @brief Here is the brief.\n# @namespace dummy.testFunctionOneLine',
                'def testFunctionOneLine():'
            ]
        }, {
            'name': 'onelineclass',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassOneLine(object):
                """Here is the brief."""''',
            'expectedOutput': [
                '## @brief Here is the brief.\n# @namespace dummy.testClassOneLine',
                'class testClassOneLine():'
            ]
        }, {
            'name': 'basicfunction',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionBrief():
                """Here is the brief.

                Here is the body. Unlike the brief
                it has multiple lines."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '#                Here is the body. Unlike the brief',
                '#                it has multiple lines.\n# @namespace dummy.testFunctionBrief',
                'def testFunctionBrief():'
            ]
        }, {
            'name': 'basicclass',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassBrief(object):
                """Here is the brief.

                Here is the body. Unlike the brief
                it has multiple lines."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '#                Here is the body. Unlike the brief',
                '#                it has multiple lines.\n# @namespace dummy.testClassBrief',
                'class testClassBrief():'
            ]
        }, {
            'name': 'basicfunctionnobrief',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionNoBrief():
                """Here is the body. It's not a brief as
                it has multiple lines."""''',
            'expectedOutput': [
                "##Here is the body. It's not a brief as",
                '#                it has multiple lines.\n# @namespace dummy.testFunctionNoBrief',
                'def testFunctionNoBrief():'
            ]
        }, {
            'name': 'basicclassnobrief',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassNoBrief(object):
                """Here is the body. It's not a brief as
                it has multiple lines."""''',
            'expectedOutput': [
                "##Here is the body. It's not a brief as",
                '#                it has multiple lines.\n# @namespace dummy.testClassNoBrief',
                'class testClassNoBrief():'
            ]
        }
    ]
    __sampleArgs = [
        {
            'name': 'onearg',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionArg(arg):
                """Here is the brief.
                Args:
                arg -- a test argument."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @param\t\targ\ta test argument.\n# @namespace dummy.testFunctionArg',
                'def testFunctionArg(arg):'
            ]
        }, {
            'name': 'multipleargs',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionArgs(arg1, arg2, arg3):
                """Here is the brief.
                Arguments:
                arg1: a test argument.
                arg2: another test argument.
                arg3: yet another test argument."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @param\t\targ1\ta test argument.',
                '# @param\t\targ2\tanother test argument.',
                '# @param\t\targ3\tyet another test argument.\n# @namespace dummy.testFunctionArgs',
                'def testFunctionArgs(arg1, arg2, arg3):'
            ]
        }, {
            'name': 'multiplelineargs',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionArgsMulti(
                        arg1,
                        arg2,
                        arg3
                    ):
                """Here is the brief.
                Arguments:
                arg1: a test argument.
                arg2: another test argument.
                arg3: yet another test argument."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @param\t\targ1\ta test argument.',
                '# @param\t\targ2\tanother test argument.',
                '# @param\t\targ3\tyet another test argument.\n# @namespace dummy.testFunctionArgsMulti',
                'def testFunctionArgsMulti(',
                '                        arg1,',
                '                        arg2,',
                '                        arg3',
                '                    ):'
            ]
        }
    ]
    __sampleAttrs = [
        {
            'name': 'oneattr',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassAttr(object):
                """Here is the brief.
                Attributes:
                attr -- a test attribute."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#\n# @namespace dummy.testClassAttr',
                'class testClassAttr():',
                '\n## @property\t\tattr\n# a test attribute.'
            ]
        }, {
            'name': 'multipleattrs',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassArgs(object):
                """Here is the brief.
                Attributes:
                attr1: a test attribute.
                attr2: another test attribute.
                attr3: yet another test attribute."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#\n# @namespace dummy.testClassArgs',
                'class testClassArgs():',
                '\n## @property\t\tattr1\n# a test attribute.',
                '\n## @property\t\tattr2\n# another test attribute.',
                '\n## @property\t\tattr3\n# yet another test attribute.'
            ]
        }
    ]
    __sampleReturns = [
        {
            'name': 'returns',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionReturns():
                """Here is the brief.
                Returns:
                Good stuff."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '# @return',
                '#                Good stuff.\n# @namespace dummy.testFunctionReturns',
                'def testFunctionReturns():'
            ]
        }, {
            'name': 'yields',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionYields():
                """Here is the brief.
                Yields:
                Good stuff."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '# @return',
                '#                Good stuff.\n# @namespace dummy.testFunctionYields',
                'def testFunctionYields():'
            ]
        }
    ]
    __sampleRaises = [
        {
            'name': 'oneraises',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionRaisesOne():
                """Here is the brief.
                Raises:
                MyException: bang bang a boom."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @exception\t\tMyException\tbang bang a boom.\n# @namespace dummy.testFunctionRaisesOne',
                'def testFunctionRaisesOne():'
            ]
        }, {
            'name': 'multipleraises',
            'visitor': 'visit_FunctionDef',
            'inputCode': '''def testFunctionRaisesMultiple():
                """Here is the brief.
                Raises:
                MyException1 -- bang bang a boom.
                MyException2 -- crash.
                MyException3 -- splatter."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @exception\t\tMyException1\tbang bang a boom.',
                '# @exception\t\tMyException2\tcrash.',
                '# @exception\t\tMyException3\tsplatter.\n# @namespace dummy.testFunctionRaisesMultiple',
                'def testFunctionRaisesMultiple():'
            ]
        }, {
            'name': 'oneraisesclass',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassRaisesOne(object):
                """Here is the brief.
                Raises:
                MyException: bang bang a boom."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @exception\t\tMyException\tbang bang a boom.\n# @namespace dummy.testClassRaisesOne',
                'class testClassRaisesOne():'
            ]
        }, {
            'name': 'multipleraisesclass',
            'visitor': 'visit_ClassDef',
            'inputCode': '''class testClassRaisesMultiple(object):
                """Here is the brief.
                Raises:
                MyException1 -- bang bang a boom.
                MyException2 -- crash.
                MyException3 -- splatter."""''',
            'expectedOutput': [
                '## @brief Here is the brief.',
                '#',
                '# @exception\t\tMyException1\tbang bang a boom.',
                '# @exception\t\tMyException2\tcrash.',
                '# @exception\t\tMyException3\tsplatter.\n# @namespace dummy.testClassRaisesMultiple',
                'class testClassRaisesMultiple():'
            ]
        }
    ]
    __linesep_for_source = '''
'''
    """
    detect the line ending within test string constants above

     -> as git can check out \n on windows too
     it's git configuration dependent if these line endings are OS specific
     or just \n.
    """

    def setUp(self):
        """
        Sets up a temporary AST for use with our unit tests.
        """
        self.options = TestDoxypypy.__Options
        self.dummyWalker = AstWalker(TestDoxypypy.__dummySrc, self.options)

    def test_stripOutAnds(self):
        """
        Test the stripOutAnds method.
        """
        testPairs = {
            'This and that.': 'This that.',
            'This & that.': 'This that.',
            'This, that, & more.': 'This, that, more.',
            'This and that & etc.': 'This that etc.',
            'Handy.': 'Handy.',
            'This, that, &c.': 'This, that, &c.'
        }
        for pair in testPairs.items():
            self.assertEqual(self.dummyWalker._stripOutAnds(pair[0]), pair[1])

    def test_endCodeIfNeeded(self):
        """
        Test the endCodeIfNeeded method.
        """
        testPairs = {
            ('unu', False): ('unu', False),
            ('du', True): ('# @endcode' + linesep + 'du', False),
            ('tri kvar', True): ('# @endcode' + linesep + 'tri kvar', False),
            ('kvin  \t', True): ('# @endcode' + linesep + 'kvin', False)
        }
        for pair in testPairs.items():
            self.assertEqual(self.dummyWalker._endCodeIfNeeded(*pair[0]),
                             pair[1])

    def test_checkIfCode(self):
        """
        Tests the checkIfCode method on the code side.
        """
        testPairs = [
            (
                [
                    'This is prose, not code.',
                    '...',
                    '>>> print("Now we have code.")'
                ], [
                    'This is prose, not code.',
                    '...{0}# @code{0}'.format(linesep),
                    '>>> print("Now we have code.")'
                ]
            ), (
                [
                    'This is prose, not code.',
                    'Traceback: frobnotz failure',
                    '>>> print("Now we have code.")'
                ], [
                    'This is prose, not code.',
                    'Traceback: frobnotz failure{0}# @code{0}'.format(linesep),
                    '>>> print("Now we have code.")'
                ]
            ), (
                [
                    'This is prose, not code.',
                    '>>> print("Now we have code.")'
                ], [
                    'This is prose, not code.{0}# @code{0}'.format(linesep),
                    '>>> print("Now we have code.")'
                ]
            ), (
                [
                    'This is prose, not code.',
                    'This is still prose, not code.',
                    'Another line of prose to really be sure.',
                    'Ditto again, still prose.',
                    '>>> print("Now we have code.")'
                ], [
                    'This is prose, not code.',
                    'This is still prose, not code.',
                    'Another line of prose to really be sure.',
                    'Ditto again, still prose.{0}# @code{0}'.format(linesep),
                    '>>> print("Now we have code.")'
                ]
            )
        ]
        for testLines, outputLines in testPairs:
            inCodeBlockObj = [False]
            codeChecker = self.dummyWalker._checkIfCode(inCodeBlockObj)
            for lineNum, line in enumerate(testLines):
                codeChecker.send((line, testLines, lineNum))
            self.assertEqual(testLines, outputLines)

    def test_checkIfProse(self):
        """
        Tests the checkIfCode method on the prose side.
        """
        testPairs = [
            (
                [
                    '...',
                    'This is prose, not code.'
                ], [
                    '...{0}# @endcode{0}'.format(linesep),
                    'This is prose, not code.'
                ]
            ), (
                [
                    'Traceback: frobnotz error',
                    'This is prose, not code.'
                ], [
                    'Traceback: frobnotz error{0}# @endcode{0}'.format(linesep),
                    'This is prose, not code.'
                ]
            ), (
                [
                    '>>> print("Code.")',
                    'This is prose, not code.'
                ], [
                    '>>> print("Code."){0}# @endcode{0}'.format(linesep),
                    'This is prose, not code.'
                ]
            ), (
                [
                    '>>> myVar = 23',
                    '>>> print(myVar)',
                    '',
                    'This is prose, not code.'
                ], [
                    '>>> myVar = 23',
                    '>>> print(myVar)',
                    '{0}# @endcode{0}'.format(linesep),
                    'This is prose, not code.'
                ]
            ), (
                [
                    '>>> myVar = 23',
                    '>>> print(myVar)',
                    '>>> myVar += 5',
                    '>>> print(myVar)',
                    '',
                    'This is prose, not code.'
                ], [
                    '>>> myVar = 23',
                    '>>> print(myVar)',
                    '>>> myVar += 5',
                    '>>> print(myVar)',
                    '{0}# @endcode{0}'.format(linesep),
                    'This is prose, not code.'
                ]
            )
        ]
        for testLines, outputLines in testPairs:
            inCodeBlockObj = [True]
            proseChecker = self.dummyWalker._checkIfCode(inCodeBlockObj)
            for lineNum, line in enumerate(testLines):
                proseChecker.send((line, testLines, lineNum))
            self.assertEqual(testLines, outputLines)

    def test_checkMemberName(self):
        """
        Test the checkMemberName method.
        """
        testPairs = {
            'public': None,
            '_protected': 'protected',
            '_stillProtected_': 'protected',
            '__private': 'private',
            '__stillPrivate_': 'private',
            '__notPrivate__': None
        }
        for pair in testPairs.items():
            self.assertEqual(self.dummyWalker._checkMemberName(pair[0]),
                             pair[1])

    def test_getFullPathName(self):
        """
        Test the getFullPathName method.
        """
        self.assertEqual(self.dummyWalker._getFullPathName([('one', 'class')]),
                         [('dummy', 'module'), ('one', 'class')])

    def test_getLines(self):
        """
        Test the getLines method.
        """
        self.assertEqual(self.dummyWalker.getLines(),
                         TestDoxypypy.__strippedDummySrc)

    def test_parseLines(self):
        """
        Test the parseLines method.
        """
        # For our sample data parseLines doesn't change anything.
        self.dummyWalker.parseLines()
        self.assertEqual(self.dummyWalker.getLines(),
                         TestDoxypypy.__strippedDummySrc)

    def snippetComparison(self, sampleSnippets):
        """
        Compare docstring parsing for a list of code snippets.
        """
        options_name = self.options.filename
        for snippetTest in sampleSnippets:
            self.options.filename = snippetTest['name'] + '.py'
            testWalker = AstWalker(snippetTest['inputCode'].split(self.__linesep_for_source),
                                   self.options)
            funcAst = parse(snippetTest['inputCode'])
            getattr(testWalker, snippetTest['visitor'])(funcAst.body[0])
            testWalker.lines[:] = [line.replace(linesep, self.__linesep_for_source)  for line in testWalker.lines]
            self.assertEqual(testWalker.lines, snippetTest['expectedOutput'])
        self.options.filename = options_name

    def test_sampleBasics(self):
        """
        Tests the proper handling of basic docstrings.
        """
        self.snippetComparison(TestDoxypypy.__sampleBasics)

    def test_sampleArgs(self):
        """
        Tests the proper handling of arguments in function docstrings.
        """
        self.snippetComparison(TestDoxypypy.__sampleArgs)

    def test_sampleAttrs(self):
        """
        Tests the proper handling of attributes in class docstrings.
        """
        self.snippetComparison(TestDoxypypy.__sampleAttrs)

    def test_sampleReturns(self):
        """
        Tests the proper handling of returns and yields in function docstrings.
        """
        self.snippetComparison(TestDoxypypy.__sampleReturns)

    def test_sampleRaises(self):
        """
        Tests the proper handling of raises in function and class docstrings.
        """
        self.snippetComparison(TestDoxypypy.__sampleRaises)

    @staticmethod
    def readAndParseFile(options, encoding="ASCII"):
        """
        Helper function to read and parse a given file and create an AST walker.
        """
        inFilename = options.filename
        # Read contents of input file.
        if encoding == 'ASCII':
            inFile = open(inFilename)
        else:
            inFile = codecsOpen(inFilename, encoding=encoding)
        lines = inFile.readlines()
        inFile.close()
        # Create the abstract syntax tree for the input file.
        testWalker = AstWalker(lines, options)
        testWalker.parseLines()
        # Output the modified source.
        return testWalker.getLines()

    def compareAgainstGoldStandard(self, inFilename, encoding="ASCII", equalIndent=False):
        """
        Compare the results against expectations.

        Read and process the input file and compare its output against the gold
        standard.
        """
        inFilenameBase = splitext(basename(inFilename))[0]
        fullPathNamespace = inFilenameBase.replace(sep, '.')
        if not equalIndent:
            trials = (
                ('.out', Namespace(
                    autobrief=True,
                    autocode=True,
                    debug=False,
                    fullPathNamespace=fullPathNamespace,
                    topLevelNamespace=inFilenameBase,
                    tablength=4,
                    filename=inFilename,
                    object_respect=False,
                    equalIndent=equalIndent,
                    keepDecorators=False
                )),
                ('.outnc', Namespace(
                    autobrief=True,
                    autocode=False,
                    debug=False,
                    fullPathNamespace=fullPathNamespace,
                    topLevelNamespace=inFilenameBase,
                    tablength=4,
                    filename=inFilename,
                    object_respect=False,
                    equalIndent=equalIndent,
                    keepDecorators=False
                )),
                ('.outnn', Namespace(
                    autobrief=True,
                    autocode=True,
                    debug=False,
                    fullPathNamespace=fullPathNamespace,
                    topLevelNamespace=None,
                    tablength=4,
                    filename=inFilename,
                    object_respect=False,
                    equalIndent=equalIndent,
                    keepDecorators=False
                )),
                ('.outbare',  Namespace(
                    autobrief=False,
                    autocode=False,
                    debug=False,
                    fullPathNamespace=fullPathNamespace,
                    topLevelNamespace=None,
                    tablength=4,
                    filename=inFilename,
                    object_respect=False,
                    equalIndent=equalIndent,
                    keepDecorators=False
                ))
            )
        else:
            trials = (('.outeq',  Namespace(
                    autobrief=True,
                    autocode=True,
                    debug=False,
                    fullPathNamespace=fullPathNamespace,
                    topLevelNamespace=None,
                    tablength=4,
                    filename=inFilename,
                    object_respect=True,
                    equalIndent=equalIndent,
                    keepDecorators=False
                )),)
                
        for options in trials:
            output = self.readAndParseFile(options[1], encoding=encoding)
            goldFilename = splitext(inFilename)[0] + options[0] + '.py'
            goldFile = open(goldFilename)
            goldContentLines = goldFile.readlines()
            goldFile.close()
            # We have to go through some extra processing to ensure line
            # endings match across platforms.
            goldContent = linesep.join(line.rstrip()
                                       for line in goldContentLines)
            self.assertEqual(output.rstrip(linesep), goldContent.rstrip(linesep))

    def test_pepProcessing(self):
        """
        Test the basic example included in PEP 257.
        """
        sampleName = 'doxypypy/test/sample_pep.py'
        self.compareAgainstGoldStandard(sampleName)

    @mark.skipif(version_info < (3, 0), reason="different behavior for Python 2")
    def test_privacyProcessing(self):
        """
        Test an example with different combinations of public, protected, and private.
        """
        sampleName = 'doxypypy/test/sample_privacy.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_googleProcessing(self):
        """
        Test the examples in the Google Python Style Guide.
        """
        sampleName = 'doxypypy/test/sample_google.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_rawdocstringProcessing(self):
        """
        Test raw docstrings.
        """
        sampleName = 'doxypypy/test/sample_rawdocstring.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_sectionsProcessing(self):
        """
        Test arbitrary sections handling.
        """
        sampleName = 'doxypypy/test/sample_sections.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_docExampleProcessing(self):
        """
        Test the basic example used in the doxypypy docs.
        """
        sampleName = 'doxypypy/test/sample_docexample.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_interfaceProcessing(self):
        """
        Test an example with ZOPE style interfaces.
        """
        sampleName = 'doxypypy/test/sample_interfaces.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_maze(self):
        """
        Test a basic example inspired by the Commodore one-liner.
        """
        sampleName = 'doxypypy/test/sample_maze.py'
        self.compareAgainstGoldStandard(sampleName)

    def test_utf8_bom(self):
        """
        Test a trivial UTF-8 file with a BOM.
        """
        sampleName = 'doxypypy/test/sample_utf8bom.py'
        self.compareAgainstGoldStandard(sampleName, encoding="UTF-8-SIG")

    def test_utf16be_bom(self):
        """
        Test a trivial UTF-16-BE file with a BOM.
        """
        sampleName = 'doxypypy/test/sample_utf16bebom.py'
        self.compareAgainstGoldStandard(sampleName, encoding="UTF-16")

    def test_utf16le_bom(self):
        """
        Test a trivial UTF-16-LE file with a BOM.
        """
        sampleName = 'doxypypy/test/sample_utf16lebom.py'
        self.compareAgainstGoldStandard(sampleName, encoding="UTF-16")

    def test_utf32be_bom(self):
        """
        Test a trivial UTF-32-BE file with a BOM.
        """
        sampleName = 'doxypypy/test/sample_utf32bebom.py'
        self.compareAgainstGoldStandard(sampleName, encoding="UTF-32")

    def test_utf32le_bom(self):
        """
        Test a trivial UTF-32-LE file with a BOM.
        """
        sampleName = 'doxypypy/test/sample_utf32lebom.py'
        self.compareAgainstGoldStandard(sampleName, encoding="UTF-32")

    @mark.skipif(version_info < (3, 0), reason="not supported in Python 2")
    def test_rstProcessing(self):
        """
        Test the examples for rst styles.
        """
        sampleName = 'doxypypy/test/sample_rstexample.py'
        self.compareAgainstGoldStandard(sampleName)

    @mark.skipif(version_info < (3, 0), reason="not supported in Python 2")
    def test_indentProcessing(self):
        """
        Test the examples with rst and indentation reduction.
        """
        sampleName = 'doxypypy/test/sample_rstexample.py'
        self.compareAgainstGoldStandard(sampleName, equalIndent=True)

    @mark.skipif(version_info < (3, 0), reason="not supported in Python 2")
    def test_asyncProcessing(self):
        """
        Test the examples with async functions and methods.
        """
        sampleName = 'doxypypy/test/sample_async.py'
        self.compareAgainstGoldStandard(sampleName)

        
if __name__ == '__main__':
    # When executed from the command line, run all the tests via unittest.
    # e.g. from root of this repository: (this makes relative module import resolving easier ...)
    #   python -m unittest doxypypy.test.test_doxypypy
    #   python -m unittest doxypypy.test.test_doxypypy.TestDoxypypy.test_sampleArgs -v --locals
    # 
    from unittest import main
    main()



# -*- coding: utf-8 -*-
"""
An asynchronous function and an asynchronous method.

Here we're testing out some straightforward Python 3 async
examples.
"""


def non_asynchronous_function():
    """
    A sample non-asynchronous function.
    """
    return "Not async."

async def asynchronous_function():
    """
    A sample asynchronous function.
    """
    return "Async"


class ClassWithAsyncMethod():
    """
    A sample class with an async method.

    Nothing special, just a basic Python 3 class that has an
    async method in it.
    """

    def non_asynchronous_method(self):
        """
        This is a regular, non-async method.
        """
        return "Not async."

    async def asynchronous_method(self):
        """
        This is an asynchronous method.
        """
        return "Async"




#!/usr/bin/env python
## @brief Google Python Style Guide SampleClass
#
#This is basically as close a copy of the Python examples in the Google
#Python Style Guide as possible while still being valid code.
# @note this is a note
# @note this is also a note
#
#http://google-styleguide.googlecode.com/svn/trunk/pyguide.html?showone=Comments#Comments
#



## @brief Fetches rows from a Bigtable.
#
#    Retrieves rows pertaining to the given keys from the Table instance
#    represented by big_table.  Silly things may happen if
#    other_silly_variable is not None.
#
#
# @param		big_table	An open Bigtable Table instance.
# @param		keys	A sequence of strings representing the key of each table row
#            to fetch.
# @param		other_silly_variable	Another optional variable, that has a much
#            longer name than the other args, and which does nothing.
#
# @return
#        A dict mapping keys to the corresponding table row data
#        fetched. Each row is represented as a tuple of strings. For
#        example:
#
# @code
#        {'Serak': ('Rigel VII', 'Preparer'),
#         'Zim': ('Irk', 'Invader'),
#         'Lrrr': ('Omicron Persei 8', 'Emperor')}
#
# @endcode
#        If a key from the keys argument is missing from the dictionary,
#        then that row was not found in the table.
#
#
# @exception		IOError	An error occurred accessing the bigtable.Table object.
#
def fetch_bigtable_rows(big_table, keys, other_silly_variable=None):
    pass


## @brief Summary of class here.
#
#    Longer class information....
#    Longer class information....
#
#
#
class SampleClass():

    ## @property		likes_spam
    # A boolean indicating if we like SPAM or not.

    ## @property		eggs
    # An integer count of the eggs we have laid.

    ## @brief Inits SampleClass with blah.
    def __init__(self, likes_spam=False):
        self.likes_spam = likes_spam
        self.eggs = 0

    ## @brief Performs operation blah.
    def public_method(self):
        pass


i = None

# We use a weighted dictionary search to find out where i is in
# the array.  We extrapolate position based on the largest num
# in the array and the array size and then do binary search to
# get the exact number.

if i & (i-1) == 0:        # true iff i is a power of 2
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
## @brief Test some restrucutred Text docstrings.
#
#It should process them into valid doxygen tags and formatings.
#
# @namespace sample_rstexample


import sys

## @brief     ExampleClass just for testing rst docstrings.
#
#    It's meant to be processed as regular text.
#
#        with literal code section
#           which is just        treated as is.
#           by doxygen.
#        until it ends on former paragraph indent.
#
#    Here is a new regular text.
#
#
# @namespace sample_rstexample.ExampleClass

class ExampleClass:
    ## @brief          Just inits a ExampleClass object.
    #
    # @namespace sample_rstexample.ExampleClass.__init__

    def __init__(self):
        self.member = "Value"

    ## @brief         And here is a typical method.
    #
    #        With parameters
    #
    #@param	new    Which holds some random string.
    #        @n type of new:  str
    #@param	other    For random number input
    #        @n type of other:  int
    #@param	yet_another    Yet another number for input.
    #        @n type of yet_another:  int, optional paramter, Default = 0
    #
    #@return  Just some result as example number
    #        @n return type of :  int
    #
    # @namespace sample_rstexample.ExampleClass.methodExample

    def methodExample(self, new : str, other: int, yet_another : int = 0) -> int:
        self.member = "NewValue" + new
        return 2 + other


## @brief     This function should work even on module level.
#
#@param	arg  [in]   <int> Some thingumabob to this function. with alternative type description.
#@return  Nothing
#
#    But describe a table of other things.
#
#    Table 1
#     With entries  |    Heads |     Cols
#    ---------------| ---------|   --------
#      1. Entry     |   Big    |     First
#      2. Entry     |  Smaller |     Third
#      3. Entry     |  Rare    |      Even
#    -              | -        |   -
#
#    And other textes too.
#
# @namespace sample_rstexample.generic_function

def generic_function(arg : int):
    print(arg)
    a = arg
    arg = a





# -*- coding: utf-8 -*-
## @brief An asynchronous function and an asynchronous method.
#
#Here we're testing out some straightforward Python 3 async
#examples.
#
# @namespace sample_async



## @brief     A sample non-asynchronous function.
#
# @namespace sample_async.non_asynchronous_function

def non_asynchronous_function():
    return "Not async."

## @brief     A sample asynchronous function.
#
# @namespace sample_async.asynchronous_function

async def asynchronous_function():
    return "Async"


## @brief     A sample class with an async method.
#
#    Nothing special, just a basic Python 3 class that has an
#    async method in it.
#
# @namespace sample_async.ClassWithAsyncMethod

class ClassWithAsyncMethod():

    ## @brief         This is a regular, non-async method.
    #
    # @namespace sample_async.ClassWithAsyncMethod.non_asynchronous_method

    def non_asynchronous_method(self):
        return "Not async."

    ## @brief         This is an asynchronous method.
    #
    # @namespace sample_async.ClassWithAsyncMethod.asynchronous_method

    async def asynchronous_method(self):
        return "Async"




#!/usr/bin/env python
# -*- coding: utf-8 -*-
## @brief Documentation Example
#
#This is the example used in the doxypypy documentation.
#It demonstrates basic docstring usage (including doctests).
#
# @namespace sample_docexample



## @brief     Does nothing more than demonstrate syntax.
#
#    This is an example of how a Pythonic human-readable docstring can
#    get parsed by doxypypy and marked up with Doxygen commands as a
#    regular input filter to Doxygen.
#
#
# @param		arg1	A positional argument.
# @param		arg2	Another positional argument.
#
#
# @param		kwarg	A keyword argument.
#
# @return
#        A string holding the result.
#
#
# @exception		ZeroDivisionError
# @exception		AssertionError
# @exception		ValueError.
#
# @par Examples
#        >>> myfunction(2, 3)
#        '5 - 0, whatever.'
#        >>> myfunction(5, 0, 'oops.')
#        Traceback (most recent call last):
#            ...
# 	ZeroDivisionError	integer division or modulo by zero
#        >>> myfunction(4, 1, 'got it.')
#        '5 - 4, got it.'
#        >>> myfunction(23.5, 23, 'oh well.')
#        Traceback (most recent call last):
#            ...
#        AssertionError
#        >>> myfunction(5, 50, 'too big.')
#        Traceback (most recent call last):
#            ...
#        ValueError
#
# @namespace sample_docexample.myfunction

def myfunction(arg1, arg2, kwarg='whatever.'):
    assert isinstance(arg1, int)
    if arg2 > 23:
        raise ValueError
    return '{0} - {1}, {2}'.format(arg1 + arg2, arg1 / arg2, kwarg)


if __name__ == "__main__":
    import doctest
    doctest.testmod()



#!/usr/bin/env python
# encoding: utf-8
##
#Raw docstrings sample module.
#
#Tests support for raw docstrings, which are necessary when docstrings contain
#escape sequences.
#
#E.g. TeX-maths:
#@f[
#  \exp(x) = \sum_{k=0}^{\infty} \frac{x^k}{k!}
#@f]
#
#Related to issue #8 [1].
#
#[1]: https://github.com/Feneric/doxypypy/issues/8
#


##Calculate the square-root of four.
#
#    Returns:
#        @f$ \sqrt{4} @f$.
#
def sqrt4():
    return 2


##Invert the given number.
#
#    Args:
#        x:  Invert this number \f$x\f$.
#
#    Returns:
#        @f$\frac{1}{x}@f$.
#
def invert(x):
    return 1/x


##Stores a polynomial.
#
#    Here, a polynomial is defined as a finite series of the form
#    @f[
#      a_0 + a_1 x + a_2 x^2 + \cdots + a_N x^N,
#    @f]
#    where \f$ a_k \f$, for \f$k=0,\ldots,N\f$, are real coefficients, and
#    \f$N\f$ is the degree of the polynomial.
#
#    Attributes:
#        coefficients:  A list of coefficients.
#
class Polynomial():

    ##Initialize a polynomial instance.
    #
    #        Args:
    #            coefficients:  A list of coefficients. Beginning with \f$a_0\f$,
    #                           and ending with \f$a_N\f$.
    #
    def __init__(self, coefficients):
        self.coefficients = coefficients

    ##Find the real roots of the polynomial.
    #
    #        I.e. all real numbers @f$ x_i @f$ for which
    #        \f[
    #          a_0 + a_1 x_i + a_2 {x_i}^2 + \cdots + a_N {x_i}^N = 0.
    #        \f]
    #
    #        Returns:
    #            A list of all real roots, or an empty list if there are none.
    #
    #        \todo Implement this method.
    #
    def find_roots(self):
        pass


##Demonstrate polynomial class.
def main():
    p = Polynomial([0, 1, 0, 2])

    print(p.coefficients)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Test some restrucutred Text docstrings.

It should process them into valid doxygen tags and formatings.
"""

import sys

class ExampleClass:
    """
    ExampleClass just for testing rst docstrings.
    
    It's meant to be processed as regular text.
    
        with literal code section
           which is just        treated as is.
           by doxygen.
        until it ends on former paragraph indent.
    
    Here is a new regular text.
    
    """
    def __init__(self):
        """
         Just inits a ExampleClass object.
        """
        self.member = "Value"
        
    def methodExample(self, new : str, other: int, yet_another : int = 0) -> int:
        """
        And here is a typical method.
        
        With parameters
        
        :param new: Which holds some random string.
        :type new: str       
        :param other: For random number input
        :type other: int
        :param yet_another: Yet another number for input.
        :type yet_another: int, optional paramter, Default = 0
        
        :return: Just some result as example number
        :rtype: int
        """
        self.member = "NewValue" + new
        return 2 + other
        

def generic_function(arg : int):
    """
    This function should work even on module level.
    
    :param [in] arg: <int> Some thingumabob to this function. with alternative type description.
    :return: Nothing
    
    But describe a table of other things.
    
    ===============  =========    ========
     With entries       Heads       Cols
    ===============  =========    ========
      1. Entry         Big          First
      2. Entry        Smaller       Third
      3. Entry        Rare           Even
    ===============  =========    ========
    
    And other textes too.
    """
    print(arg)
    a = arg
    arg = a
    
    


# -*- coding: utf-8 -*-
"""
Typical class with private members.

Here we're just trying to make a fairly straightforward class
that has some private (Python-enforced private, name-mangled)
and protected (by convention only, a.k.a. "bed lump")
variables.
"""
__notPrivateModuleAttr__ = 1
__privateModuleAttr = 2
_protectedModuleAttr = 3


class NewStyleSample(object):
    """
    A sample new-style class.

    Nothing special, just a basic new-style class that has some
    private and protected members in it.
    """

    __notPrivateClassAttr__ = 1
    __privateClassAttr = 2
    _protectedClassAttr = 3

    def __init__(self):
        """
        This constructor won't be private.
        """
        self.__notPrivateAttr__ = 1
        self.__privateAttr = 2
        self._protectedAttr = 3

    def __notPrivateClassMethod__(self):
        """
        This will be not be private.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    def __privateClassMethod(self):
        """
        This will be private.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    def _protectedClassMethod(self):
        """
        This will be protected.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    def publicClassMethod(self):
        """
        This will be public.
        """
        public = 0
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.public = public
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    @staticmethod
    def publicClassStaticMethod():
        """
        This static method will be public.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    @classmethod
    def publicClassClassMethod(self):
        """
        This class method will be public.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    class __innerNotPrivate__(object):
        """
        An inner not private class.

        Nothing special, just a not private helper class.
        """

        def __init__(self):
            """
            This constructor won't be private.
            """
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    class __innerProtected(object):
        """
        An inner protected class.

        Nothing special, just a protected helper class.
        """

        def __init__(self):
            """
            This constructor won't be private.
            """
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    class __innerPrivate(object):
        """
        An inner private class.

        Nothing special, just a private helper class.
        """

        def __init__(self):
            """
            This constructor won't be private.
            """
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3


class OldStyleSample():
    """
    A sample old-style class.

    Nothing special, just a basic old-style class that has some
    private and protected members in it.
    """

    __notPrivateClassAttr__ = 1
    __privateClassAttr = 2
    _protectedClassAttr = 3

    def __init__(self):
        """
        This constructor won't be private.
        """
        self.__notPrivateAttr__ = 1
        self.__privateAttr = 2
        self._protectedAttr = 3

    def __notPrivateClassMethod__(self):
        """
        This will be not be private.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    def __privateClassMethod(self):
        """
        This will be private.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    def _protectedClassMethod(self):
        """
        This will be protected.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    def publicClassMethod(self):
        """
        This will be public.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr

    @staticmethod
    def publicClassStaticMethod():
        """
        This static method will be public.
        """
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    @classmethod
    def publicClassClassMethod(self):
        """
        This class method will be public.
        """
        public = 0
        __notPrivateAttr__ = 1
        __privateAttr = 2
        _protectedAttr = 3
        self.public = public
        self.__notPrivateAttr__ = __notPrivateAttr__
        self.__privateAttr = __privateAttr
        self._protectedAttr = _protectedAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    class __innerNotPrivate__():
        """
        An inner not private class.

        Nothing special, just a not private helper class.
        """

        def __init__(self):
            """
            This constructor won't be private.
            """
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    class __innerProtected():
        """
        An inner protected class.

        Nothing special, just a protected helper class.
        """

        def __init__(self):
            """
            This constructor won't be private.
            """
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3

    class __innerPrivate():
        """
        An inner private class.

        Nothing special, just a private helper class.
        """

        def __init__(self):
            """
            This constructor won't be private.
            """
            self.public = 0
            self.__notPrivateAttr__ = 1
            self.__privateAttr = 2
            self._protectedAttr = 3


def Function():
    """
    A sample function.

    Nothing special, just a basic function that has some private
    and protected variables in it.
    """
    __notPrivateFunctionAttr__ = 1
    __privateFunctionAttr = 2
    _protectedFunctionAttr = 3

    def __notPrivateFunction__():
        """
        This will not be private.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def __privateNestedFunction():
        """
        This will be private.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def _protectedNestedFunction():
        """
        This will be protected.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def publicNestedFunction():
        """
        This will be public.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction


def _ProtectedFunction():
    """
    A sample protected function.

    Nothing special, just a basic protected function that has some
    private and protected variables in it.
    """
    __notPrivateFunctionAttr__ = 1
    __privateFunctionAttr = 2
    _protectedFunctionAttr = 3

    def __notPrivateFunction__():
        """
        This will not be private.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def __privateNestedFunction():
        """
        This will be private.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def _protectedNestedFunction():
        """
        This will be protected.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def publicNestedFunction():
        """
        This will be public.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction


def __PrivateFunction():
    """
    A sample private function.

    Nothing special, just a basic private function that has some
    private and protected variables in it.
    """
    __notPrivateFunctionAttr__ = 1
    __privateFunctionAttr = 2
    _protectedFunctionAttr = 3

    def __notPrivateFunction__():
        """
        This will not be private.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def __privateNestedFunction():
        """
        This will be private.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def _protectedNestedFunction():
        """
        This will be protected.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    def publicNestedFunction():
        """
        This will be public.
        """
        __notPrivateAttr__ = __notPrivateFunctionAttr__
        __privateAttr = __privateFunctionAttr
        _protectedAttr = _protectedFunctionAttr
        return __notPrivateAttr__ + __privateAttr + _protectedAttr

    return __notPrivateFunction__ + __privateNestedFunction \
        + _protectedNestedFunction + publicNestedFunction



#!/usr/bin/env python
# encoding: utf-8
##
#Sample documentation the arbitrary section handling.
#
#Related to issue #7 [1].
#
#[1]: https://github.com/Feneric/doxypypy/issues/7
#


##A simple function of two arguments.
#
#    This function takes two arguments, but does absolutely nothing with them.
#    However, it sends out a friendly greeting to the world.
#
#    Args:
#        arg1:  The first argument
#        arg2:  The second argument
#
#    Returns:
#        A string stating "Hello World"
#
#    Examples:
#        >>> function(1, 2)
#        "Hello World"
#        >>> function('a', 'b')
#        "Hello World"
#
#    Intent:
#        The intent is to demonstrate sections like this one within docstrings.
#        How they behave with multiple lines.
#
#        And how they behave with multiple paragraphs.
#        That contain multiple lines.
#
#    Paragraphs standing by themselves without indentation, should be left alone.
#
def function(arg1, arg2):
    return "Hello World"



# -*- coding: utf-8 -*-
"""
Typical interfaces definition.

Here we're just trying to make some typical interface definitions
to better test the doxypypy filter.
"""

from zope.interface import Interface, Attribute

# Public API Interfaces


class INul(Interface):
    """
    The zeroth sample interface.

    Nothing special, just a sample interface to help test the
    filter. This is a special case commonly known as a "marker
    interface" that declares neither methods nor attributes.
    """


class IUnu(Interface):
    """
    The first sample interface.

    Nothing special, just a sample interface to help test the
    filter. This one has just a single method.
    """

    def unuMethod(unuArg, *args):
        """The first method offered for the first interface."""


class IDu(Interface):
    """
    The second sample interface.

    Nothing special, just a sample interface to help test the
    filter. This one has multiple methods.
    """

    def duMethod(duArg1, duArg2):
        """The first method offered for the second interface."""

    def duMethod2(duArg1, **kwargs):
        """The second method offered for the second interface."""


class ITri(Interface):
    """
    The third sample interface.

    Nothing special, just a sample interface to help test the
    filter. This one has just a single attribute.
    """

    triAttr = Attribute('the first attribute for the third interface')


class IKvar(Interface):
    """
    The fourth sample interface.

    Nothing special, just a sample interface to help test the
    filter. This one has multiple attributes.
    """

    kvarAttr1 = Attribute('the first attribute for the fourth interface')

    kvarAttr2 = Attribute('the second attribute for the fourth interface')


class IKvin(Interface):
    """
    The fifth sample interface.

    Nothing special, just a sample interface to help test the
    filter. This one opens things up a little and has multiple
    attributes and methods.
    """

    kvinAttr1 = Attribute('the first attribute for the fifth interface')

    kvinAttr2 = Attribute('the second attribute for the fifth interface')

    def kvinMethod(kvinArg1, kvinArg2, *args, **kwargs):
        """The first method offered for the fifth interface."""

    def kvinMethod2(kvinArg1, kvinArg2='default'):
        """The second method offered for the fifth interface."""

    kvinAttr3 = Attribute('the third attribute for the fifth interface')

    def kvinMethod3(kvinArg1, kvinArg2='default'):
        """The third method offered for the fifth interface."""



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Generate a simple maze pattern.

Tip of the hat to both the original Commodore 64 program and the book
"10 Print Chr$(205.5+rnd(1)); Goto 10" that it inspired.

Note that this is neither the shortest nor the most faithful way to
write this program in Python. Rather it is being used as a simple
example for the doxypypy Doxygen input filter for Python and makes use
of features like keyword arguments and generators and has a docstring
that documents them both appropriately.
"""

from sys import stdout
from random import choice


def generateBlock(blockOptions=u"╱╲"):
    """
    Generates a single block of a maze.

    This simple generator randomly picks a character from a list (the two
    diagonal lines by default) and returns it on each iteration.

    Kwargs:
        blockOptions -- The list of characters to choose from.

    Yields:
        A single character chosen from blockOptions.
    """
    while True:
        yield choice(blockOptions)


# Establish our block generator and generate a series of blocks.
blockGenerator = generateBlock()
blockCount = 0
while blockCount < 3200:
    blockCount += 1
    print(next(blockGenerator)),
    # Deal with Python's extra space print weirdness.
    stdout.softspace = False



# -*- coding: utf-8 -*-
## @brief Typical interfaces definition.
#
#Here we're just trying to make some typical interface definitions
#to better test the doxypypy filter.
#
# @namespace sample_interfaces


from zope.interface import Interface, Attribute

# Public API Interfaces


## @brief     The zeroth sample interface.
#
#    Nothing special, just a sample interface to help test the
#    filter. This is a special case commonly known as a "marker
#    interface" that declares neither methods nor attributes.
#
# @namespace sample_interfaces.INul
# @interface INul

class INul(Interface):

    pass


## @brief     The first sample interface.
#
#    Nothing special, just a sample interface to help test the
#    filter. This one has just a single method.
#
# @namespace sample_interfaces.IUnu
# @interface IUnu

class IUnu(Interface):

    pass

    ## @brief The first method offered for the first interface.
    # @namespace sample_interfaces.IUnu.unuMethod
    def unuMethod(unuArg, *args):

        pass


## @brief     The second sample interface.
#
#    Nothing special, just a sample interface to help test the
#    filter. This one has multiple methods.
#
# @namespace sample_interfaces.IDu
# @interface IDu

class IDu(Interface):

    pass

    ## @brief The first method offered for the second interface.
    # @namespace sample_interfaces.IDu.duMethod
    def duMethod(duArg1, duArg2):

        pass

    ## @brief The second method offered for the second interface.
    # @namespace sample_interfaces.IDu.duMethod2
    def duMethod2(duArg1, **kwargs):

        pass


## @brief     The third sample interface.
#
#    Nothing special, just a sample interface to help test the
#    filter. This one has just a single attribute.
#
# @namespace sample_interfaces.ITri
# @interface ITri

class ITri(Interface):

    pass

    ## @property triAttr
    # the first attribute for the third interface
    # @hideinitializer
    triAttr = Attribute('the first attribute for the third interface')


## @brief     The fourth sample interface.
#
#    Nothing special, just a sample interface to help test the
#    filter. This one has multiple attributes.
#
# @namespace sample_interfaces.IKvar
# @interface IKvar

class IKvar(Interface):

    pass

    ## @property kvarAttr1
    # the first attribute for the fourth interface
    # @hideinitializer
    kvarAttr1 = Attribute('the first attribute for the fourth interface')

    ## @property kvarAttr2
    # the second attribute for the fourth interface
    # @hideinitializer
    kvarAttr2 = Attribute('the second attribute for the fourth interface')


## @brief     The fifth sample interface.
#
#    Nothing special, just a sample interface to help test the
#    filter. This one opens things up a little and has multiple
#    attributes and methods.
#
# @namespace sample_interfaces.IKvin
# @interface IKvin

class IKvin(Interface):

    pass

    ## @property kvinAttr1
    # the first attribute for the fifth interface
    # @hideinitializer
    kvinAttr1 = Attribute('the first attribute for the fifth interface')

    ## @property kvinAttr2
    # the second attribute for the fifth interface
    # @hideinitializer
    kvinAttr2 = Attribute('the second attribute for the fifth interface')

    ## @brief The first method offered for the fifth interface.
    # @namespace sample_interfaces.IKvin.kvinMethod
    def kvinMethod(kvinArg1, kvinArg2, *args, **kwargs):

        pass

    ## @brief The second method offered for the fifth interface.
    # @namespace sample_interfaces.IKvin.kvinMethod2
    def kvinMethod2(kvinArg1, kvinArg2='default'):

        pass

    ## @property kvinAttr3
    # the third attribute for the fifth interface
    # @hideinitializer
    kvinAttr3 = Attribute('the third attribute for the fifth interface')

    ## @brief The third method offered for the fifth interface.
    # @namespace sample_interfaces.IKvin.kvinMethod3
    def kvinMethod3(kvinArg1, kvinArg2='default'):

        pass



#!/usr/bin/env python
# encoding: utf-8
r"""
Raw docstrings sample module.

Tests support for raw docstrings, which are necessary when docstrings contain
escape sequences.

E.g. TeX-maths:
@f[
  \exp(x) = \sum_{k=0}^{\infty} \frac{x^k}{k!}
@f]

Related to issue #8 [1].

[1]: https://github.com/Feneric/doxypypy/issues/8
"""


def sqrt4():
    r"""Calculate the square-root of four.

    Returns:
        @f$ \sqrt{4} @f$.
    """
    return 2


def invert(x):
    r"""Invert the given number.

    Args:
        x:  Invert this number \f$x\f$.

    Returns:
        @f$\frac{1}{x}@f$.
    """
    return 1/x


class Polynomial(object):
    r"""Stores a polynomial.

    Here, a polynomial is defined as a finite series of the form
    @f[
      a_0 + a_1 x + a_2 x^2 + \cdots + a_N x^N,
    @f]
    where \f$ a_k \f$, for \f$k=0,\ldots,N\f$, are real coefficients, and
    \f$N\f$ is the degree of the polynomial.

    Attributes:
        coefficients:  A list of coefficients.
    """

    def __init__(self, coefficients):
        r"""Initialize a polynomial instance.

        Args:
            coefficients:  A list of coefficients. Beginning with \f$a_0\f$,
                           and ending with \f$a_N\f$.
        """
        self.coefficients = coefficients

    def find_roots(self):
        r"""Find the real roots of the polynomial.

        I.e. all real numbers @f$ x_i @f$ for which
        \f[
          a_0 + a_1 x_i + a_2 {x_i}^2 + \cdots + a_N {x_i}^N = 0.
        \f]

        Returns:
            A list of all real roots, or an empty list if there are none.

        \todo Implement this method.
        """
        pass


def main():
    """Demonstrate polynomial class."""
    p = Polynomial([0, 1, 0, 2])

    print(p.coefficients)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# encoding: utf-8
"""
Sample documentation the arbitrary section handling.

Related to issue #7 [1].

[1]: https://github.com/Feneric/doxypypy/issues/7
"""


def function(arg1, arg2):
    """A simple function of two arguments.

    This function takes two arguments, but does absolutely nothing with them.
    However, it sends out a friendly greeting to the world.

    Args:
        arg1:  The first argument
        arg2:  The second argument

    Returns:
        A string stating "Hello World"

    Examples:
        >>> function(1, 2)
        "Hello World"
        >>> function('a', 'b')
        "Hello World"

    Intent:
        The intent is to demonstrate sections like this one within docstrings.
        How they behave with multiple lines.

        And how they behave with multiple paragraphs.
        That contain multiple lines.

    Paragraphs standing by themselves without indentation, should be left alone.
    """
    return "Hello World"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Documentation Example

This is the example used in the doxypypy documentation.
It demonstrates basic docstring usage (including doctests).
"""


def myfunction(arg1, arg2, kwarg='whatever.'):
    """
    Does nothing more than demonstrate syntax.

    This is an example of how a Pythonic human-readable docstring can
    get parsed by doxypypy and marked up with Doxygen commands as a
    regular input filter to Doxygen.

    Args:
        arg1:   A positional argument.
        arg2:   Another positional argument.

    Kwargs:
        kwarg:  A keyword argument.

    Returns:
        A string holding the result.

    Raises:
        ZeroDivisionError, AssertionError, & ValueError.

    Examples:
        >>> myfunction(2, 3)
        '5 - 0, whatever.'
        >>> myfunction(5, 0, 'oops.')
        Traceback (most recent call last):
            ...
        ZeroDivisionError: integer division or modulo by zero
        >>> myfunction(4, 1, 'got it.')
        '5 - 4, got it.'
        >>> myfunction(23.5, 23, 'oh well.')
        Traceback (most recent call last):
            ...
        AssertionError
        >>> myfunction(5, 50, 'too big.')
        Traceback (most recent call last):
            ...
        ValueError
    """
    assert isinstance(arg1, int)
    if arg2 > 23:
        raise ValueError
    return '{0} - {1}, {2}'.format(arg1 + arg2, arg1 / arg2, kwarg)


if __name__ == "__main__":
    import doctest
    doctest.testmod()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Setup file for the doxypypy package."""

from setuptools import setup, find_packages
from os.path import dirname, join
from os import chdir

if dirname(__file__):
    chdir(dirname(__file__))

setup(
    name='doxypypy',
    version='0.8.8.7',
    description='A Doxygen filter for Python',
    long_description=open(join(dirname(__file__), 'README.rst')).read(),
    keywords='Doxygen filter Python documentation',
    author='Eric W. Brown',
    url='https://github.com/Feneric/doxypypy',
    packages=find_packages(),
    install_requires=[
        'chardet'
    ],
    test_suite='doxypypy.test.test_doxypypy',
    extras_require={
        'testing': ['pytest', 'tox'],
    },
    entry_points={
        'console_scripts': [
            'doxypypy = doxypypy.doxypypy:main'
        ]
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Environment :: Plugins',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Topic :: Software Development :: Documentation'
    ]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
##
#Test some restrucutred Text docstrings.
#
#It should process them into valid doxygen tags and formatings.
#

import sys

##
#    ExampleClass just for testing rst docstrings.
#
#    It's meant to be processed as regular text.
#
#        with literal code section
#           which is just        treated as is.
#           by doxygen.
#        until it ends on former paragraph indent.
#
#    Here is a new regular text.
#
#
class ExampleClass:
    ##
    #         Just inits a ExampleClass object.
    #
    def __init__(self):
        self.member = "Value"

    ##
    #        And here is a typical method.
    #
    #        With parameters
    #
    #        :param new: Which holds some random string.
    #        :type new: str
    #        :param other: For random number input
    #        :type other: int
    #        :param yet_another: Yet another number for input.
    #        :type yet_another: int, optional paramter, Default = 0
    #
    #        :return: Just some result as example number
    #        :rtype: int
    #
    def methodExample(self, new : str, other: int, yet_another : int = 0) -> int:
        self.member = "NewValue" + new
        return 2 + other


##
#    This function should work even on module level.
#
#    :param [in] arg: <int> Some thingumabob to this function. with alternative type description.
#    :return: Nothing
#
#    But describe a table of other things.
#
#    ===============  =========    ========
#     With entries       Heads       Cols
#    ===============  =========    ========
#      1. Entry         Big          First
#      2. Entry        Smaller       Third
#      3. Entry        Rare           Even
#    ===============  =========    ========
#
#    And other textes too.
#
def generic_function(arg : int):
    print(arg)
    a = arg
    arg = a





#!/usr/bin/env python
"""
Google Python Style Guide SampleClass

This is basically as close a copy of the Python examples in the Google
Python Style Guide as possible while still being valid code.
NOTE: this is a note
NOTE: this is also a note

http://google-styleguide.googlecode.com/svn/trunk/pyguide.html?showone=Comments#Comments
"""


def fetch_bigtable_rows(big_table, keys, other_silly_variable=None):
    """Fetches rows from a Bigtable.

    Retrieves rows pertaining to the given keys from the Table instance
    represented by big_table.  Silly things may happen if
    other_silly_variable is not None.

    Args:
        big_table: An open Bigtable Table instance.
        keys: A sequence of strings representing the key of each table row
            to fetch.
        other_silly_variable: Another optional variable, that has a much
            longer name than the other args, and which does nothing.

    Returns:
        A dict mapping keys to the corresponding table row data
        fetched. Each row is represented as a tuple of strings. For
        example:

        {'Serak': ('Rigel VII', 'Preparer'),
         'Zim': ('Irk', 'Invader'),
         'Lrrr': ('Omicron Persei 8', 'Emperor')}

        If a key from the keys argument is missing from the dictionary,
        then that row was not found in the table.

    Raises:
        IOError: An error occurred accessing the bigtable.Table object.
    """
    pass


class SampleClass(object):
    """Summary of class here.

    Longer class information....
    Longer class information....

    Attributes:
        likes_spam: A boolean indicating if we like SPAM or not.
        eggs: An integer count of the eggs we have laid.
    """

    def __init__(self, likes_spam=False):
        """Inits SampleClass with blah."""
        self.likes_spam = likes_spam
        self.eggs = 0

    def public_method(self):
        """Performs operation blah."""
        pass


i = None

# We use a weighted dictionary search to find out where i is in
# the array.  We extrapolate position based on the largest num
# in the array and the array size and then do binary search to
# get the exact number.

if i & (i-1) == 0:        # true iff i is a power of 2
    pass
